@@ -1,6 +1,6 @@
 from .PyReplayBuffer import (ReplayBuffer,PrioritizedReplayBuffer,
                              SelectiveReplayBuffer)
-from .PyReplayBuffer import create_buffer
+from .PyReplayBuffer import create_buffer, train
 
 try:
     from .util import create_env_dict, create_before_add_func
